@@ -1,6 +1,6 @@
 # VC  -  underpinnings of a VC-agnostic diff and commit tool.
 
-# Copyright (C) 2006-2011 Free Software Foundation, Inc.
+# Copyright (C) 2006-2013 Free Software Foundation, Inc.
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -55,6 +55,7 @@ my $vc_cmd =
    },
    GIT() =>
    {
+    AUTHOR_FMT => '--author=%s',
     DIFF_COMMAND => [qw(git diff -B -C HEAD --)],
     DIFF_PRISTINE => [qw(git diff --no-ext-diff -B -C HEAD --)],
     VALID_DIFF_EXIT_STATUS => {0 => 1},
@@ -78,6 +79,7 @@ my $vc_cmd =
    },
    BZR() => # aka bazaar
    {
+    AUTHOR_FMT => '--author=%s',
     DIFF_COMMAND => [qw(bzr diff --)],
     VALID_DIFF_EXIT_STATUS => {0 => 1, 1 => 1},
     COMMIT_COMMAND => [qw(bzr ci -q -F)],
@@ -189,6 +191,15 @@ sub diff_cmd()
   return @$cmd_ref;
 }
 
+sub author_option()
+{
+  my $self = shift;
+  my $author = shift;
+  my $fmt = $vc_cmd->{$self->name()}->{AUTHOR_FMT};
+  my $opt = $fmt ? sprintf ($fmt, $author) : undef;
+  return $opt;
+}
+
 # Print diff -u style diffs, regardless of envvar settings
 # like GIT_EXTERNAL_DIFF or options like git's --ext-diff.
 # If no DIFF_PRISTINE member is specified, just use DIFF_COMMAND.
